:py:mod:`holisticai.explainability.plots`
===========================================

.. automodule:: holisticai.explainability.plots
    :no-members:
    :no-inherited-members:


**Feature Importance**

.. autosummary::
    :nosignatures:
    :template: function.rst
    :toctree: .generated/
    
    plot_feature_importance

**Partial Dependencies**

.. autosummary::
    :nosignatures:
    :template: function.rst
    :toctree: .generated/
    
    plot_partial_dependence

**Surrogate**

.. autosummary::
    :nosignatures:
    :template: function.rst
    :toctree: .generated/
    
    plot_surrogate